@@ -1,18 +1,18 @@
-import os
-
 import json
+import os
 from datetime import datetime
 
 import numpy as np
-import numpy.testing.utils as nptu
+import numpy.testing as nptu
 import pytest
-
-from maggma.stores import GridFSStore, MongoStore
-from maggma.stores.gridfs import files_collection_fields, GridFSURIStore
 from pymongo.errors import ConfigurationError
 
+from maggma.core import StoreError
+from maggma.stores import GridFSStore, MongoStore
+from maggma.stores.gridfs import GridFSURIStore, files_collection_fields
 
-@pytest.fixture
+
+@pytest.fixture()
 def mongostore():
     store = MongoStore("maggma_test", "test")
     store.connect()
@@ -20,9 +20,20 @@ def mongostore():
     store._collection.drop()
 
 
-@pytest.fixture
-def gridfsstore():
-    store = GridFSStore("maggma_test", "test", key="task_id")
+@pytest.fixture(params=["std", "uri"])
+def gridfsstore(request):
+    """
+    Fixture providing both a standard GridFSStore and a GridFSURIStore.
+    """
+    store_type = request.param
+    if store_type == "std":
+        store = GridFSStore("maggma_test", "test", key="task_id")
+    elif store_type == "uri":
+        store = GridFSURIStore(
+            uri="mongodb://localhost:27017", database="maggma_test", collection_name="test", key="task_id"
+        )
+    else:
+        raise ValueError(f"Unknown store_type {store_type}")
     store.connect()
     yield store
     store._files_collection.drop()
@@ -34,47 +45,30 @@ def test_update(gridfsstore):
     data2 = np.random.rand(256)
     tic = datetime(2018, 4, 12, 16)
     # Test metadata storage
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}]
-    )
-    assert (
-        gridfsstore._files_collection.find_one({"metadata.task_id": "mp-1"}) is not None
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}])
+    assert gridfsstore._files_collection.find_one({"metadata.task_id": "mp-1"}) is not None
 
     # Test storing data
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data2, gridfsstore.last_updated_field: tic}])
     assert len(list(gridfsstore.query({"task_id": "mp-1"}))) == 1
     assert "task_id" in gridfsstore.query_one({"task_id": "mp-1"})
-    nptu.assert_almost_equal(
-        gridfsstore.query_one({"task_id": "mp-1"})["data"], data2, 7
-    )
+    nptu.assert_almost_equal(gridfsstore.query_one({"task_id": "mp-1"})["data"], data2, 7)
 
     # Test storing compressed data
     gridfsstore = GridFSStore("maggma_test", "test", key="task_id", compression=True)
     gridfsstore.connect()
     gridfsstore.update([{"task_id": "mp-1", "data": data1}])
-    assert (
-        gridfsstore._files_collection.find_one({"metadata.compression": "zlib"})
-        is not None
-    )
+    assert gridfsstore._files_collection.find_one({"metadata.compression": "zlib"}) is not None
 
-    nptu.assert_almost_equal(
-        gridfsstore.query_one({"task_id": "mp-1"})["data"], data1, 7
-    )
+    nptu.assert_almost_equal(gridfsstore.query_one({"task_id": "mp-1"})["data"], data1, 7)
 
 
 def test_remove(gridfsstore):
     data1 = np.random.rand(256)
     data2 = np.random.rand(256)
     tic = datetime(2018, 4, 12, 16)
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}]
-    )
-    gridfsstore.update(
-        [{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}])
+    gridfsstore.update([{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}])
 
     assert gridfsstore.query_one(criteria={"task_id": "mp-1"})
     assert gridfsstore.query_one(criteria={"task_id": "mp-2"})
@@ -87,15 +81,11 @@ def test_count(gridfsstore):
     data1 = np.random.rand(256)
     data2 = np.random.rand(256)
     tic = datetime(2018, 4, 12, 16)
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}])
 
     assert gridfsstore.count() == 1
 
-    gridfsstore.update(
-        [{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}])
 
     assert gridfsstore.count() == 2
     assert gridfsstore.count({"task_id": "mp-2"}) == 1
@@ -105,12 +95,8 @@ def test_query(gridfsstore):
     data1 = np.random.rand(256)
     data2 = np.random.rand(256)
     tic = datetime(2018, 4, 12, 16)
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}]
-    )
-    gridfsstore.update(
-        [{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}])
+    gridfsstore.update([{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}])
 
     doc = gridfsstore.query_one(criteria={"task_id": "mp-1"})
     nptu.assert_almost_equal(doc["data"], data1, 7)
@@ -136,26 +122,18 @@ def test_last_updated(gridfsstore):
     data2 = np.random.rand(256)
     tic = datetime(2018, 4, 12, 16)
 
-    gridfsstore.update(
-        [{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}]
-    )
-    gridfsstore.update(
-        [{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-1", "data": data1, gridfsstore.last_updated_field: tic}])
+    gridfsstore.update([{"task_id": "mp-2", "data": data2, gridfsstore.last_updated_field: tic}])
 
     assert gridfsstore.last_updated == tic
 
     toc = datetime(2019, 6, 12, 16)
-    gridfsstore.update(
-        [{"task_id": "mp-3", "data": data2, gridfsstore.last_updated_field: toc}]
-    )
+    gridfsstore.update([{"task_id": "mp-3", "data": data2, gridfsstore.last_updated_field: toc}])
 
     assert gridfsstore.last_updated == toc
 
     tic = datetime(2017, 6, 12, 16)
-    gridfsstore.update(
-        [{"task_id": "mp-4", "data": data2, gridfsstore.last_updated_field: tic}]
-    )
+    gridfsstore.update([{"task_id": "mp-4", "data": data2, gridfsstore.last_updated_field: tic}])
 
     assert gridfsstore.last_updated == toc
 
@@ -218,7 +196,7 @@ def test_index(gridfsstore):
 
 def test_gfs_metadata(gridfsstore):
     """
-    Ensure metadata is put back in the docuemnt
+    Ensure metadata is put back in the document
     """
     tic = datetime(2018, 4, 12, 16)
 
@@ -244,13 +222,9 @@ def test_gridfsstore_from_launchpad_file(lp_file):
 
 
 def test_searchable_fields(gridfsstore):
-
     tic = datetime(2018, 4, 12, 16)
 
-    data = [
-        {"task_id": f"mp-{i}", "a": i, gridfsstore.last_updated_field: tic}
-        for i in range(3)
-    ]
+    data = [{"task_id": f"mp-{i}", "a": i, gridfsstore.last_updated_field: tic} for i in range(3)]
     gridfsstore.searchable_fields = ["task_id"]
     gridfsstore.update(data, key="a")
 
@@ -259,13 +233,9 @@ def test_searchable_fields(gridfsstore):
 
 
 def test_additional_metadata(gridfsstore):
-
     tic = datetime(2018, 4, 12, 16)
 
-    data = [
-        {"task_id": f"mp-{i}", "a": i, gridfsstore.last_updated_field: tic}
-        for i in range(3)
-    ]
+    data = [{"task_id": f"mp-{i}", "a": i, gridfsstore.last_updated_field: tic} for i in range(3)]
 
     gridfsstore.update(data, key="a", additional_metadata="task_id")
 
@@ -284,6 +254,7 @@ def test_gridfs_uri():
     is_name = store.name is uri
     # This is try and keep the secret safe
     assert is_name
+    store.close()
 
 
 def test_gridfs_uri_dbname_parse():
@@ -299,3 +270,12 @@ def test_gridfs_uri_dbname_parse():
     uri_with_db = "mongodb://uuu:xxxx@host:27017"
     with pytest.raises(ConfigurationError):
         GridFSURIStore(uri_with_db, "test")
+
+
+def test_close(gridfsstore):
+    assert gridfsstore.query_one() is None
+    gridfsstore.close()
+    with pytest.raises(StoreError):
+        gridfsstore.query_one()
+    # reconnect to allow the drop of the collection in the fixture
+    gridfsstore.connect()
